bayesianbandits.api.EpsilonGreedy
=================================

.. currentmodule:: bayesianbandits.api

.. autoclass:: EpsilonGreedy

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EpsilonGreedy.__init__
   
   

   
   
   